@@ -8,6 +8,7 @@ from airflow.models import BaseOperator, DagRun, TaskInstance
 
 from astro.utils.load_dataframe import move_dataframe_to_sql
 from astro.utils.task_id_helper import get_task_id
+from astro.sql.table import Table
 
 
 class AgnosticLoadFile(BaseOperator):
@@ -26,25 +27,17 @@ class AgnosticLoadFile(BaseOperator):
     def __init__(
         self,
         path="",
-        output_table_name=None,
+        output_table: Table =None,
         file_conn_id="",
-        output_conn_id="",
         chunksize=None,
-        database: Optional[str] = None,
-        schema: Optional[str] = None,
-        warehouse: Optional[str] = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.path = path
         self.chunksize = chunksize
         self.file_conn_id = file_conn_id
-        self.output_conn_id = output_conn_id
-        self.database = database
-        self.schema = schema
-        self.warehouse = warehouse
         self.kwargs = kwargs
-        self.output_table_name = output_table_name
+        self.output_table = output_table
 
     def execute(self, context):
         """Loads csv/parquet table from local/S3/GCS with Pandas.
@@ -56,18 +49,16 @@ class AgnosticLoadFile(BaseOperator):
         df = self._load_dataframe(self.path)
 
         # Retrieve conn type
-        conn_type = BaseHook.get_connection(self.output_conn_id).conn_type
         move_dataframe_to_sql(
-            output_table_name=self.output_table_name,
+            output_table_name=self.output_table.table_name,
+            conn_id=self.output_table.conn_id,
+            database=self.output_table.database,
+            warehouse=self.output_table.warehouse,
+            schema=self.output_table.schema,
             df=df,
-            conn_type=conn_type,
-            conn_id=self.output_conn_id,
-            database=self.database,
-            schema=self.schema,
-            warehouse=self.warehouse,
-            chunksize=self.chunksize,
+            conn_type=BaseHook.get_connection(self.output_table.conn_id).conn_type,
         )
-        return self.output_table_name
+        return self.output_table
 
     @staticmethod
     def validate_path(path):
@@ -119,7 +110,7 @@ class AgnosticLoadFile(BaseOperator):
 
 def load_file(
     path,
-    output_table_name=None,
+    output_table=None,
     file_conn_id=None,
     output_conn_id=None,
     database=None,
@@ -149,11 +140,7 @@ def load_file(
     return AgnosticLoadFile(
         task_id=task_id,
         path=path,
-        output_table_name=output_table_name,
+        output_table=output_table,
         file_conn_id=file_conn_id,
-        output_conn_id=output_conn_id,
-        database=database,
-        schema=schema,
-        warehouse=warehouse,
         **kwargs,
     ).output
